#include <queue>
#include <vector>
#include <climits>
#include <iostream>
using namespace std;

#define rep(i, n) for(int i = 0; i < n; i++)

typedef long long ll;
typedef pair<ll, ll> pii;

const int maxnodes = 215;
const ll inf = (ll)2e6;

int nodes = maxnodes;
int prio[maxnodes], curflow[maxnodes], prevedge[maxnodes], prevnode[maxnodes], q[maxnodes], pot[maxnodes];
bool inqueue[maxnodes];

struct Edge {
  int to, f, cap, cost, rev;
};

vector<Edge> graph[maxnodes];

void addEdge(int s, int t, int cap, int cost) {
  Edge a = {t, 0, cap, cost, graph[t].size()};
  Edge b = {s, 0, 0, -cost, graph[s].size()};
  graph[s].push_back(a);
  graph[t].push_back(b);
}

void bellmanFord(int s, int dist[]) {
  fill(dist, dist + nodes, INT_MAX);
  dist[s] = 0;
  int qt = 0;
  q[qt++] = s;
  for (int qh = 0; (qh - qt) % nodes != 0; qh++) {
    int u = q[qh % nodes];
    inqueue[u] = false;
    for (int i = 0; i < (int) graph[u].size(); i++) {
      Edge &e = graph[u][i];
      if (e.cap <= e.f) continue;
      int v = e.to;
      int ndist = dist[u] + e.cost;
      if (dist[v] > ndist) {
        dist[v] = ndist;
        if (!inqueue[v]) {
          inqueue[v] = true;
          q[qt++ % nodes] = v;
        }
      }
    }
  }
}

pii minCostFlow(int s, int t, int maxf) {
// bellmanFord can be safely commented if edges costs are non-negative
  bellmanFord(s, pot);
  int flow = 0;
  int flowCost = 0;
  while (flow < maxf) {
    priority_queue<ll, vector<ll>, greater<ll> > q;
    q.push(s);
    fill(prio, prio + nodes, INT_MAX);
    prio[s] = 0;
    curflow[s] = INT_MAX;
    while (!q.empty()) {
      ll cur = q.top();
      int d = cur >> 32;
      int u = cur;
      q.pop();
      if (d != prio[u])
        continue;
      for (int i = 0; i < (int) graph[u].size(); i++) {
        Edge &e = graph[u][i];
        int v = e.to;
        if (e.cap <= e.f) continue;
        int nprio = prio[u] + e.cost + pot[u] - pot[v];
        if (prio[v] > nprio) {
          prio[v] = nprio;
          q.push(((ll) nprio << 32) + v);
          prevnode[v] = u;
          prevedge[v] = i;
          curflow[v] = min(curflow[u], e.cap - e.f);
        }
      }
    }
    if (prio[t] == INT_MAX)
      break;
    for (int i = 0; i < nodes; i++)
      pot[i] += prio[i];
    int df = min(curflow[t], maxf - flow);
    flow += df;
    for (int v = t; v != s; v = prevnode[v]) {
      Edge &e = graph[prevnode[v]][prevedge[v]];
      e.f += df;
      graph[v][e.rev].f -= df;
      flowCost += df * e.cost;
    }
  }
  return make_pair(flow, flowCost);
}

int f(int x) {
	if(x % 2 == 0)
		return x + 1;
	return x - 1;
}

int main() {
	ll n, k;
	cin >> n >> k;
	n++;
	rep(i, n)
		for(int j = i + 1; j < n; j++) {
			int w;
			cin >> w;
			addEdge(i * 2 + 1, j * 2, 1, w);
		}
	rep(i, n) {
		if(i) {
			addEdge(i * 2, f(i * 2), 1, -inf);
			addEdge(f(i * 2), n * 2 + 1, 1, 0);
		}
		else {
			addEdge(i * 2, f(i * 2), k, 0);
			addEdge(1, n * 2 + 1, k, 0);
		}
	}
	addEdge(n * 2, 0, k, 0);

	// cout << INT_MAX << ' ' << (1 >> 32) << endl;

	nodes = n * 2 + 2;
	int s = n * 2;
	int t = n * 2 + 1;
	// cout << LONG_MAX << endl;
	pii res = minCostFlow(s, t, INT_MAX);
	ll flow = res.first;
	ll flowCost = res.second;
	// cout << flow << endl;
	// cout << flowCost << endl;
	cout << flowCost + inf * (n - 1) << endl;
}